@@ -5,7 +5,7 @@ use warnings;
 use base 'My::Builder';
 
 use File::Spec::Functions qw(catdir catfile rel2abs);
-use File::Spec qw(devnull);
+use File::Spec;
 use File::Glob qw(glob);
 use File::Copy;
 use Config;
@@ -35,6 +35,10 @@ sub build_binaries {
 
   #make options
   my @makeopts   = qw[USE_NODEPEND=Yes];
+  
+  #XXX-FIXME
+  #push(@makeopts, 'EXTRA_CFLAGS=-DIUP_IMGLIB_LARGE') if $self->notes('build_large_imglib');
+  warn "Large built-in images not supported on Cygwin platform\n" if $self->notes('build_large_imglib');
 
   #store debug info into ConfigData
   $self->config_data('info_imtargets', \@imtargets);
